@@ -1,9 +1,7 @@
 from negmas import LinearUtilityFunction
 
-from .indneg import (
-    IndependentNegotiationsAgent,
-    MarketAwareIndependentNegotiationsAgent,
-)
+from .indneg import IndependentNegotiationsAgent
+from .indneg import MarketAwareIndependentNegotiationsAgent
 
 __all__ = ["BuyCheapSellExpensiveAgent", "MarketAwareBuyCheapSellExpensiveAgent"]
 
@@ -13,8 +11,8 @@ class BuyCheapSellExpensiveAgent(IndependentNegotiationsAgent):
 
     def create_ufun(self, is_seller: bool, issues=None, outcomes=None):
         if is_seller:
-            return LinearUtilityFunction((1, 1, 10))
-        return LinearUtilityFunction((1, -1, -10))
+            return LinearUtilityFunction((1, 1, 10), issues=issues, outcomes=outcomes)
+        return LinearUtilityFunction((1, -1, -10), issues=issues, outcomes=outcomes)
 
 
 class MarketAwareBuyCheapSellExpensiveAgent(
