@@ -9,15 +9,13 @@ import numpy as np
 from negmas import LinearUtilityFunction
 
 from scml.scml2020.components import IndependentNegotiationsManager
-from scml.scml2020.components import StepNegotiationManager
 from scml.scml2020.components import MovingRangeNegotiationManager
+from scml.scml2020.components import StepNegotiationManager
 from scml.scml2020.components import SupplyDrivenProductionStrategy
 
-from ..components.signing import KeepOnlyGoodPrices
-from ..components.trading import (
-    PredictionBasedTradingStrategy,
-)
 from ..components.prediction import MarketAwareTradePredictionStrategy
+from ..components.signing import KeepOnlyGoodPrices
+from ..components.trading import PredictionBasedTradingStrategy
 from ..world import SCML2020Agent
 
 __all__ = [
@@ -129,8 +127,8 @@ class IndDecentralizingAgent(
 ):
     def create_ufun(self, is_seller: bool, issues=None, outcomes=None):
         if is_seller:
-            return LinearUtilityFunction((1, 1, 10))
-        return LinearUtilityFunction((1, -1, -10))
+            return LinearUtilityFunction((1, 1, 10), issues=issues, outcomes=outcomes)
+        return LinearUtilityFunction((1, -1, -10), issues=issues, outcomes=outcomes)
 
 
 class MarketAwareIndDecentralizingAgent(
