@@ -2,6 +2,7 @@
 
 from negmas import Issue
 from negmas import RandomUtilityFunction
+from negmas.outcomes.issue_ops import enumerate_issues
 
 from .indneg import IndependentNegotiationsAgent
 
@@ -12,7 +13,10 @@ class RandomAgent(IndependentNegotiationsAgent):
     """An agent that negotiates randomly."""
 
     def create_ufun(self, is_seller: bool, issues=None, outcomes=None):
+        if issues:
+            outcomes = None
         return RandomUtilityFunction(
-            outcomes if outcomes is not None else Issue.enumerate(issues, astype=tuple),
+            issues=issues,
+            outcomes=outcomes,
             reserved_value=0.0,
         )
