@@ -1,14 +1,19 @@
 import copy
 from unittest import mock
 
+import hypothesis.strategies as st
 import numpy as np
 import pytest
-import hypothesis.strategies as st
-from hypothesis import given, example
-
-from scml.scml2020 import FactoryProfile, Factory, NO_COMMAND, FactoryState
-from hypothesis.stateful import RuleBasedStateMachine, Bundle, rule
+from hypothesis import example
+from hypothesis import given
+from hypothesis.stateful import Bundle
+from hypothesis.stateful import RuleBasedStateMachine
+from hypothesis.stateful import rule
 
+from scml.scml2020 import NO_COMMAND
+from scml.scml2020 import Factory
+from scml.scml2020 import FactoryProfile
+from scml.scml2020 import FactoryState
 from scml.scml2020.components.simulation import FactorySimulator
 
 PROCESSES = 5
